<?php if ( ! defined( 'FW' ) ) die( 'Forbidden' );

class FW_Extension_Member extends FW_Extension {
    private $post_type = 'ht-member';
    private $post_type_slug = 'member';

    public function _init(){
        $this->ht_define_slugs();
        add_action( 'init', array( $this, 'ht_action_register_post_type' ) );
    }

    private function ht_define_slugs(){
        $this->post_type_slug = apply_filters('ht-member-slug', $this->post_type_slug);
    }

    public function ht_action_register_post_type(){
        $post_names = array(
			'singular' => __( 'Member', 'filmic' ),
			'plural'   => __( 'Members', 'filmic' )
		);

		register_post_type( $this->post_type,
			array(
				'labels'             => array(
					'name'               => $post_names['plural'],
					'singular_name'      => $post_names['singular'],
					'add_new'            => __( 'Add New', 'filmic' ),
					'add_new_item'       => sprintf( __( 'Add New %s', 'filmic' ), $post_names['singular'] ),
					'edit'               => __( 'Edit', 'filmic' ),
					'edit_item'          => sprintf( __( 'Edit %s', 'filmic' ), $post_names['singular'] ),
					'new_item'           => sprintf( __( 'New %s', 'filmic' ), $post_names['singular'] ),
					'all_items'          => sprintf( __( 'All %s', 'filmic' ), $post_names['plural'] ),
					'view'               => sprintf( __( 'View %s', 'filmic' ), $post_names['singular'] ),
					'view_item'          => sprintf( __( 'View %s', 'filmic' ), $post_names['singular'] ),
					'search_items'       => sprintf( __( 'Search %s', 'filmic' ), $post_names['plural'] ),
					'not_found'          => sprintf( __( 'No %s Found', 'filmic' ), $post_names['plural'] ),
					'not_found_in_trash' => sprintf( __( 'No %s Found In Trash', 'filmic' ), $post_names['plural'] ),
					'parent_item_colon'  => '' /* text for parent types */
				),
				'description'        => __( 'Create a member', 'filmic' ),
				'public'             => true,
				'show_ui'            => true,
				'show_in_menu'       => true,
				'show_in_nav_menus' 	=> true,
				'publicly_queryable' => true,
				/* queries can be performed on the front end */
				'has_archive'        => true,
				'rewrite'            => array('slug' => $this->post_type_slug),
				'menu_position'      => 6,
				'show_in_nav_menus'  => true,
				'menu_icon'          => 'dashicons-groups',
				'hierarchical'       => false,
				'query_var'          => true,
				'supports'           => array(
					'title', /* Text input field to create a post title. */
					'editor',
                    'excerpt',
					'thumbnail', /* Displays a box for featured image. */
				),
				'capabilities'       => array(
					'edit_post'              => 'edit_pages',
					'read_post'              => 'edit_pages',
					'delete_post'            => 'edit_pages',
					'edit_posts'             => 'edit_pages',
					'edit_others_posts'      => 'edit_pages',
					'publish_posts'          => 'edit_pages',
					'read_private_posts'     => 'edit_pages',
					'read'                   => 'edit_pages',
					'delete_posts'           => 'edit_pages',
					'delete_private_posts'   => 'edit_pages',
					'delete_published_posts' => 'edit_pages',
					'delete_others_posts'    => 'edit_pages',
					'edit_private_posts'     => 'edit_pages',
					'edit_published_posts'   => 'edit_pages',
				),
			) );
    }

	public function get_post_type_name() {
		return $this->post_type;
	}
}